@@ -107,6 +107,7 @@ MainWindow::MainWindow(QWidget *parent)
     }
     ui->menuMain->setTitle(""); // remove the title so we don't get options like "Menu / Settings" instead of "Settings"
     qDebug() << "MainWindow::MainWindow(): Finished";
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 }
 
 MainWindow::~MainWindow()
@@ -191,7 +192,7 @@ void MainWindow::cancelScan() {
 }
 
 void MainWindow::startScan() {
-    videoWidget->useVideosrc();
+    //videoWidget->useVideosrc();
     videoWidget->start();
     ui->btnScan->setVisible(false);
     ui->btnRefocus->setVisible(true);
@@ -306,8 +307,8 @@ void MainWindow::on_btnOpenImage_clicked()
     if(!qfi.exists())
         return;
 
-    videoWidget->useFilesrc(fileName);
-    videoWidget->start();
+    //videoWidget->useFilesrc(fileName);
+    //videoWidget->start();
 
     // but how do we stop the pipeline? Or does it stop itself once it's processed the image, probably
 
