@@ -61,6 +61,10 @@ public:
     void start();
     void stop();
     bool isFocusing();
+    void useVideosrc();
+    void useFilesrc(QString filename);
+
+
 signals:
     void focusingValueChanged(bool enabled);
 private:
@@ -78,8 +82,13 @@ private:
     void getDeviceType();
     bool pipelineReady;
     BarcodeDetector *decoder;
+
     // added from appdata.h
     GstElement *camera_src;
+    GstElement *file_src;
+    GstElement *input_selector;
+    GstElement *video_crop;
+
     gboolean isportrait;
     gboolean accelerometers;
     DBusConnection *con;
